/*
 * Copyright 2009 NaoTeam Humboldt
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.hu_berlin.informatik.ki.jxabsleditor;

import java.io.File;
import java.util.Properties;
import javax.swing.JFileChooser;

/**
 *
 * @author Heinrich Mellmann
 */
public class OptionsDialog extends javax.swing.JDialog
{

  public static final String DEFAULT_COMPILATION_PATH = "defaultCompilationPath";
  public static final String XABSL_COMPILER_COMMAND = "xabslCompilerCommand";
  private Properties configuration;

  /** Creates new form Options */
  public OptionsDialog(java.awt.Frame parent, boolean modal, Properties configuration)
  {
    super(parent, modal);
    initComponents();
    this.setTitle("Options");

    this.configuration = configuration;
    loadOptions();
  }

  private void loadOptions()
  {

    if(configuration.containsKey(DEFAULT_COMPILATION_PATH))
    {
      this.txtDefaultCompilationPath.setText(configuration.getProperty(DEFAULT_COMPILATION_PATH));
    }

    if(configuration.containsKey(XABSL_COMPILER_COMMAND))
    {
      this.txtXabslCompilerCommand.setText(configuration.getProperty(XABSL_COMPILER_COMMAND));
    }
  }//end loadOptions

  /** This method is called from within the constructor to
   * initialize the form.
   * WARNING: Do NOT modify this code. The content of this method is
   * always regenerated by the Form Editor.
   */
  @SuppressWarnings("unchecked")
  // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
  private void initComponents() {

    fileChooserCompilationPath = new javax.swing.JFileChooser();
    jButtonOK = new javax.swing.JButton();
    txtDefaultCompilationPath = new javax.swing.JTextField();
    jLabel2 = new javax.swing.JLabel();
    btBrowseCompilation = new javax.swing.JButton();
    jButtonOK1 = new javax.swing.JButton();
    jLabel3 = new javax.swing.JLabel();
    txtXabslCompilerCommand = new javax.swing.JTextField();

    fileChooserCompilationPath.setFileSelectionMode(javax.swing.JFileChooser.DIRECTORIES_ONLY);

    setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
    setLocationByPlatform(true);
    setModal(true);
    setName("Options"); // NOI18N
    setResizable(false);

    jButtonOK.setText("OK");
    jButtonOK.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(java.awt.event.ActionEvent evt) {
        jButtonOKActionPerformed(evt);
      }
    });

    jLabel2.setText("Default compilation path");

    btBrowseCompilation.setText("Browse...");
    btBrowseCompilation.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(java.awt.event.ActionEvent evt) {
        btBrowseCompilationActionPerformed(evt);
      }
    });

    jButtonOK1.setText("Cancel");
    jButtonOK1.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(java.awt.event.ActionEvent evt) {
        jButtonOK1ActionPerformed(evt);
      }
    });

    jLabel3.setText("XABSL Compiler command");

    javax.swing.GroupLayout layout = new javax.swing.GroupLayout(getContentPane());
    getContentPane().setLayout(layout);
    layout.setHorizontalGroup(
      layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
      .addGroup(layout.createSequentialGroup()
        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
          .addGroup(layout.createSequentialGroup()
            .addContainerGap()
            .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
              .addComponent(jLabel2)
              .addComponent(txtDefaultCompilationPath, javax.swing.GroupLayout.PREFERRED_SIZE, 289, javax.swing.GroupLayout.PREFERRED_SIZE))
            .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
            .addComponent(btBrowseCompilation))
          .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
            .addGap(305, 305, 305)
            .addComponent(jButtonOK1, javax.swing.GroupLayout.DEFAULT_SIZE, 91, Short.MAX_VALUE))
          .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
            .addGap(305, 305, 305)
            .addComponent(jButtonOK, javax.swing.GroupLayout.DEFAULT_SIZE, 91, Short.MAX_VALUE))
          .addGroup(layout.createSequentialGroup()
            .addContainerGap()
            .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
              .addComponent(txtXabslCompilerCommand, javax.swing.GroupLayout.DEFAULT_SIZE, 390, Short.MAX_VALUE)
              .addGroup(layout.createSequentialGroup()
                .addComponent(jLabel3)
                .addGap(124, 124, 124)))))
        .addContainerGap())
    );
    layout.setVerticalGroup(
      layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
      .addGroup(layout.createSequentialGroup()
        .addContainerGap()
        .addComponent(jLabel2)
        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
          .addComponent(txtDefaultCompilationPath, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
          .addComponent(btBrowseCompilation))
        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
        .addComponent(jLabel3)
        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
        .addComponent(txtXabslCompilerCommand, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 43, Short.MAX_VALUE)
        .addComponent(jButtonOK)
        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
        .addComponent(jButtonOK1)
        .addContainerGap())
    );

    pack();
  }// </editor-fold>//GEN-END:initComponents

    private void jButtonOKActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jButtonOKActionPerformed


      // save settings
      if("".equals(txtDefaultCompilationPath.getText()) && configuration.containsKey(DEFAULT_COMPILATION_PATH))
      {
        configuration.remove(DEFAULT_COMPILATION_PATH);
      }
      else
      {
        configuration.setProperty(DEFAULT_COMPILATION_PATH, txtDefaultCompilationPath.getText());
      }

      if("".equals(txtXabslCompilerCommand.getText()) && configuration.containsKey(XABSL_COMPILER_COMMAND))
      {
        configuration.remove(XABSL_COMPILER_COMMAND);
      }
      else
      {
        configuration.setProperty(XABSL_COMPILER_COMMAND,
          txtXabslCompilerCommand.getText());
      }

      this.setVisible(false);
      this.dispose();
    }//GEN-LAST:event_jButtonOKActionPerformed

    private void btBrowseCompilationActionPerformed(java.awt.event.ActionEvent evt)//GEN-FIRST:event_btBrowseCompilationActionPerformed
    {//GEN-HEADEREND:event_btBrowseCompilationActionPerformed

      File fPath = new File(System.getProperty("user.dir"));
      if(!"".equals(txtDefaultCompilationPath.getText()))
      {
        fPath = new File(txtDefaultCompilationPath.getText());
        
      }

      fileChooserCompilationPath.setSelectedFile(fPath);
      if(fileChooserCompilationPath.showOpenDialog(this) == JFileChooser.APPROVE_OPTION)
      {
        txtDefaultCompilationPath.setText(fileChooserCompilationPath.getSelectedFile().getAbsolutePath());
      }

}//GEN-LAST:event_btBrowseCompilationActionPerformed

    private void jButtonOK1ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jButtonOK1ActionPerformed
      this.setVisible(false);
      this.dispose();
    }//GEN-LAST:event_jButtonOK1ActionPerformed

  // Variables declaration - do not modify//GEN-BEGIN:variables
  private javax.swing.JButton btBrowseCompilation;
  private javax.swing.JFileChooser fileChooserCompilationPath;
  private javax.swing.JButton jButtonOK;
  private javax.swing.JButton jButtonOK1;
  private javax.swing.JLabel jLabel2;
  private javax.swing.JLabel jLabel3;
  private javax.swing.JTextField txtDefaultCompilationPath;
  private javax.swing.JTextField txtXabslCompilerCommand;
  // End of variables declaration//GEN-END:variables
}
